==> ejc-front-impl-3.0.1-20210729.082737-65-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeModulePro.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

/**
 * 发布的历史记录表
 */
public class IdeModulePro implements Serializable {

	private static final long serialVersionUID = 1L;

	private Long id;
	private String code;
	private String name;
	private Long appId;
	private String data;
	private String appCode;
	private String appName;
	private String appResourceData;
	private String pageType;
	private double verNum; // 页面发布版本号
	private Long fromId;
	private String fromName;// 来源地址
	private Long toId;
	private String toName;// 目标地址
	private String billTypeCode;

	private Date createDate;
	private Long createId;
	private Integer isDelete;
	private Date modifyDate;
	private Long modifyId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getData() {
		return data;
	}

	public void setData(String data) {
		this.data = data;
	}

	public String getAppCode() {
		return appCode;
	}

	public void setAppCode(String appCode) {
		this.appCode = appCode;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getAppResourceData() {
		return appResourceData;
	}

	public void setAppResourceData(String appResourceData) {
		this.appResourceData = appResourceData;
	}

	public String getPageType() {
		return pageType;
	}

	public void setPageType(String pageType) {
		this.pageType = pageType;
	}

	public double getVerNum() {
		return verNum;
	}

	public void setVerNum(double verNum) {
		this.verNum = verNum;
	}

	public Long getFromId() {
		return fromId;
	}

	public void setFromId(Long fromId) {
		this.fromId = fromId;
	}

	public String getFromName() {
		return fromName;
	}

	public void setFromName(String fromName) {
		this.fromName = fromName;
	}

	public Long getToId() {
		return toId;
	}

	public void setToId(Long toId) {
		this.toId = toId;
	}

	public String getToName() {
		return toName;
	}

	public void setToName(String toName) {
		this.toName = toName;
	}

	public String getBillTypeCode() {
		return billTypeCode;
	}

	public void setBillTypeCode(String billTypeCode) {
		this.billTypeCode = billTypeCode;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

}

==> ejc-front-impl-3.0.1-20230710.061131-158-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeModulePro.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

/**
 * 发布的历史记录表
 */
public class IdeModulePro implements Serializable {

	private static final long serialVersionUID = 1L;

	private Long id;
	private String code;
	private String name;
	private Long appId;
	private String data;
	private String enData;
	private String appCode;
	private String appName;
	private String appResourceData;
	private String pageType;
	private double verNum; // 页面发布版本号
	private Long fromId;
	private String fromName;// 来源地址
	private Long toId;
	private String toName;// 目标地址
	private String billTypeCode;

	private Date createDate;
	private Long createId;
	private Integer isDelete;
	private Date modifyDate;
	private Long modifyId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getData() {
		return data;
	}

	public void setData(String data) {
		this.data = data;
	}

	public String getEnData() {
		return enData;
	}

	public void setEnData(String enData) {
		this.enData = enData;
	}

	public String getAppCode() {
		return appCode;
	}

	public void setAppCode(String appCode) {
		this.appCode = appCode;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getAppResourceData() {
		return appResourceData;
	}

	public void setAppResourceData(String appResourceData) {
		this.appResourceData = appResourceData;
	}

	public String getPageType() {
		return pageType;
	}

	public void setPageType(String pageType) {
		this.pageType = pageType;
	}

	public double getVerNum() {
		return verNum;
	}

	public void setVerNum(double verNum) {
		this.verNum = verNum;
	}

	public Long getFromId() {
		return fromId;
	}

	public void setFromId(Long fromId) {
		this.fromId = fromId;
	}

	public String getFromName() {
		return fromName;
	}

	public void setFromName(String fromName) {
		this.fromName = fromName;
	}

	public Long getToId() {
		return toId;
	}

	public void setToId(Long toId) {
		this.toId = toId;
	}

	public String getToName() {
		return toName;
	}

	public void setToName(String toName) {
		this.toName = toName;
	}

	public String getBillTypeCode() {
		return billTypeCode;
	}

	public void setBillTypeCode(String billTypeCode) {
		this.billTypeCode = billTypeCode;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

}
